
#ifndef _C13_sh642_
#define _C13_sh642_

#ifdef __cplusplus
extern "C" {
#endif

RTOSHF (EIF_REFERENCE,10212)
static EIF_REFERENCE F743_10212_body(EIF_REFERENCE);
extern EIF_REFERENCE F743_10212(EIF_REFERENCE);
extern void EIF_Minit642(void);

#ifdef __cplusplus
}
#endif

#endif
